import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import I18n
import Dialog

import "../core"
import "../widgets"

BaseForm {
    id: root
    objectName: "payWithBonusForm"
    Style.class: "payWithBonusForm"

    property var action: DialogState.actions[Context.id.value]

    contentItem: ColumnLayout {
        id: mainLayout
        objectName: "mainLayout"
        spacing: 40

        SGroupBox {
            objectName: "payWithBonusBox"
            topPadding: 280

            contentItem: ColumnLayout {
                objectName: "payWithBonusLayout"
                spacing: 80
                Layout.alignment: Qt.AlignHCenter

                SLabel {
                    objectName: "payWithBonusTitle"
                    Style.class: "payWithBonusTitle"
                    Tr { code: "bonusInfoTitle" }
                    Layout.alignment: Qt.AlignHCenter
                }

                GridLayout {
                    objectName: "payWithBonusInfoLayout"
                    columns: 1
                    rowSpacing: 12
                    Layout.alignment: Qt.AlignHCenter | Qt.AlignTop

                    SvgImage {
                        objectName: "payWithBonusCard"
                        source: Style.parameter("image.payWithBonusCard")
                        Layout.alignment: Qt.AlignHCenter

                        GridLayout {
                            objectName: "payWithBonusCardInfoLayout"
                            property int generalMargin: 40
                            property int sideCardShadow: 26
                            property int bottomCardShadow: 52
                            anchors {
                                fill: parent
                                topMargin: generalMargin
                                leftMargin: generalMargin + sideCardShadow
                                rightMargin: generalMargin + sideCardShadow
                                bottomMargin: generalMargin + bottomCardShadow
                            }
                            rows: 2
                            columns: 2

                            Repeater {
                                model: [
                                    {
                                        columnSpan: parent.columns, trCode: "bonusInfoBalance",
                                        valueStyle: "payWithBonusBalanceValue", value: Money.format(root.action.balance)
                                    },
                                    {
                                        columnSpan: 1, trCode: "bonusInfoEarn",
                                        valueStyle: "payWithBonusEarnSpendValue", value: Money.format(root.action.earn)
                                    },
                                    {
                                        columnSpan: 1, trCode: "bonusInfoSpend",
                                        valueStyle: "payWithBonusEarnSpendValue", value: Money.format(root.action.result)
                                    }
                                ]
                                delegate: ColumnLayout {
                                    Layout.columnSpan: modelData.columnSpan
                                    Layout.alignment: model.row === 0 ? Qt.AlignTop : Qt.AlignBottom
                                    SLabel {
                                        objectName: "payWithBonusCardInfoName"
                                        Style.class: "payWithBonusCardInfoName"
                                        Tr { code: modelData.trCode }
                                    }
                                    SLabel {
                                        objectName: "payWithBonusCardInfoValue"
                                        Style.class: modelData.valueStyle
                                        text: modelData.value
                                    }
                                }
                            }
                        }
                    }

                    ColumnLayout {
                        id: payWithBonusBonusInfoLayout
                        objectName: "payWithBonusBonusInfoLayout"
                        spacing: 40
                        Layout.alignment: Qt.AlignHCenter

                        Repeater {
                            model: [
                                {
                                    trCode: "bonusInfoDue", valueStyle: "payWithBonusDueValue",
                                    value: Money.format(Money.create(root.action.due.value - root.action.result.value))
                                },
                                {
                                    trCode: "bonusInfoAvailable", valueStyle: "payWithBonusAvailableValue",
                                    value: Money.format(Money.create(root.action.canSpend.value - root.action.result.value))
                                }
                            ]
                            delegate: ColumnLayout {
                                spacing: 10
                                Layout.alignment: payWithBonusBonusInfoLayout.Layout.alignment

                                SLabel {
                                    objectName: "payWithBonusBonusInfoName"
                                    Style.class: "payWithBonusBonusInfoName"
                                    Tr { code: modelData.trCode }
                                    Layout.alignment: payWithBonusBonusInfoLayout.Layout.alignment
                                }
                                SLabel {
                                    objectName: "payWithBonusBonusInfoValue"
                                    Style.class: modelData.valueStyle
                                    text: modelData.value
                                    Layout.alignment: payWithBonusBonusInfoLayout.Layout.alignment
                                }
                            }
                        }
                    }
                }
            }

            Layout.fillHeight: true
            Layout.fillWidth: true
        }

        RowLayout {
            objectName: "payWithBonusButtonsLayout"
            spacing: 40

            ActionButton {
                objectName: "payWithBonusCloseButton"
                Style.class: "payWithBonusCloseButton"
                implicitWidth: 1
                Tr { code: "bonusInfoClose" }
                onClicked: removeContext()

                Layout.fillWidth: true
                Layout.preferredHeight: parent.Layout.maximumHeight
            }

            ActionButton {
                objectName: "payWithBonusSpendBonusButton"
                Style.class: "payWithBonusSpendBonusButton"
                implicitWidth: 1
                visible: root.action.hasBalance
                Tr { code: "spendBonus" }

                onClicked: {
                    let inputBonusesToPay = Action.create("DIALOG_INPUT", {})

                    inputBonusesToPay.success.connect((action) => {
                                              if (action.text)
                                                root.action = DialogState.actions[Context.id.value]
                                          })

                    PluginManager.async(inputBonusesToPay)
                }

                Layout.fillWidth: true
                Layout.preferredHeight: parent.Layout.maximumHeight
            }

            Layout.fillWidth: true
            Layout.maximumHeight: 110
        }
    }
}
